# __init__.py
#from . import *
from colorama import init
from datetime import datetime as sj
from time import sleep as dd
from math import pi as pai1
from sys import exit as tc
start=sj.now()
from pdsystem import *


#log.py
#准备一年，更新更新，优化，优化
#2021.7.16 #项目上传
# 即将更新log:1把每个判断放到input下面2print ('{} '.format(j))3.过多的无效代码行
# 优化部分显示
#增加自述文件
#############
#ver2.5.4.1
#修复一个小bug
#ver2.6.1
'''修复一个print,2.6是为了方便打包改的
优化beginning文件，但无改动'''

#原模块为3y现在更名为a_3y
#----------ycc------------
#更名 ycc
#支持命令行运行了
#修复eval,bug
#版本号更改
#自述文件更新
#keywords修改
#----------ycc0.3.2--------
#setup 修改,依赖包修改
#修改配置文件
#-----------ycc0.3.8--------
#美化在pypi上的显示
#-----------ycc0.4-----------
#修复因意外导致的bug
#优化一下显示 2020.8.1
#-----------sycc(定制版)
#正式开通
#即将y,yz更新，try,except,print(done!)
#程序名字改新名，但下载方式与链接不变


from sys import path
path.append('..')
#from e.__init__ import *
from p.beginnings import *
from colorama import init
from datetime import datetime as sj
from time import sleep as dd
from math import pi as pai1
from sys import exit as tc
start=sj.now()

#switch(1)


from p.__init__ import * #检测8-12是否需要备份
pai2='π'
from sys import path
path.append('..')
from e.__init__ import *
import platform
os=platform.system()
def part_y():#圆
    while True:
        r=input('请输入圆的半径:')
        try:
            r=eval(r)
            if r<=0:
            	print('请输入有效数字')
            	print('0.5s后切换模式')
            	switch(0.5)
            	break
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            print('请输入有效数字')
            print('出现\033[6;31mError\033[0m\n')
            print('请选择\033[6;36m圆\033[0m\033[1;1m模式重试')
            switch(2)
            break
        print('【圆】')
        aboutpi()
        if os=='Linux':
            xxx=input('请输入(\033[1;32m1,2,3,4,5\033[0m\033[1;1m)中的一个数字:')
        elif os=='Windows':
            xxx=input('请输入1~5中的数字')
        print('')
        try:
            xxx=int(xxx)
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            print('请输入指定范围的整数,不可以使用运算符')
            switch(0.3)
            break
        try:
        	if xxx>5 or xxx<=0:
        		end1=sj.now()-start
        		print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在3s后关闭,谢谢使用')
        		exitings(3)
        		tc('谢谢使用')
        	elif xxx==5:
        		print('-'*40)
        		switch(0.3)
        		break
        	elif xxx==1:
        		d=2*r #直径
        		ra=r**2
        		s=3.14*ra#面积
        		c=3.14*d#周长
        		dw()
        		print('======计算结果======')
        		print('当半径=',r,'直径=',d,'时')
        		print('周长=','{:.3f}'.format(c))
        		print('面积=','{:.3f}'.format(s))
        	elif xxx==2:
        	    d=2*r #直径
        	    ra=r**2
        	    s=pai1*ra#面积
        	    c=pai1*d
        	    dw()
        	    print('======计算结果======')
        	    print('当半径=',r,'直径=',d,'时')
        	    print('周长=','{:.3f}'.format(c))
        	    print('面积=','{:.3f}'.format(s))
        	elif xxx==3:
        	    d=2*r #直径
        	    ra=r**2
        	    s=ra#面积
        	    c=r*2 #周长
        	    dw()
        	    print('======计算结果======')
        	    print('当半径=',r,'直径=',d,'时')
        	    print('周长=','{:.5f}'.format(c),pai2)
        	    print('面积=','{:.5f}'.format(s),pai2)
        	elif xxx==4:
        	    defpi=input('请输入要自定义的π(大于等于3且小于3.2)->')
        	    try:
        	        defpi=eval(defpi)
        	    except ZeroDivisionError:
        	        print('除数不能为0')
        	    except (Exception,ValueError,TypeError,IOError,KeyboardInterrupt):
        	        print('请输入指定范围的数字')
        	    if defpi<3 or defpi >3.2:
        	        end=sj.now()-start
        	        print('本次使用时间:',end)
        	        print('^大于3小于3.2^|||5s后关闭')
        	        exitings(5)
        	        tc('谢谢使用')
        	    elif (defpi >=3 and defpi <3.2):
        	        d=2*r 
        	        ra=r**2
        	        s=defpi*ra
        	        c=defpi*d
        	        dw()
        	        print('======计算结果======')
        	        print('当半径=',r,'直径=',d,'π=',defpi,'时')
        	        print('周长=','{:.6f}'.format(c))
        	        print('面积=','{:.6f}'.format(s))
        	else:
        	    end1=sj.now()-start
        	    print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5s后关闭,谢谢使用')
        	    exitings(5)
        	    tc('谢谢使用')
        except Exception:
            print('圆beta报告:在本模式中您的操作出现\033[1;1m\033[6;31mError\033[0m\n','\b已为您自动跳转选择模式,请选择圆模式')
            switch(1)
            break


import sys as s
from __init__ import * #排好顺序start变量覆盖
from p.__init__ import *
from k.test import *
from p.y import *
from p.yh import *
from p.yz import *
def wf():
    print('\r请稍等，全力加载中')
    for i in range(1,5):    
        s.stdout.write("██")
        if i == 4:
            s.stdout.write("██" +"100%"+'\nBegin!')
        s.stdout.flush()
        dd(0.5)

def main():
    pdios()
    wf()
    user_key()
    A()
    print('\033[1;1m 由于更换颜色太费时费力,所以只加入了部分颜色,请谅解')
    print('\033[7;36m本次开始使用时间:\033[0m','\033[7;32m',start,'\033[0m')
    while True:
        print('\033[1;1m【虹源三式】')
        print('=====切换/选择模式，请选择=====\n模式1.计算关于圆的计算(输入1执行)\n模式2.计算关于圆柱的计算(输入2执行)\n模式3.计算关于圆环的计算(输入3执行)\n输入其他数字退出\n')
        yyy=input('请选择模式(输入数字):')
        try:
            yyy=eval(yyy)
        except (IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            print('请输入正确数字')
        except ZeroDivisionError:
            print('除数不能为0，emmm，2年级小孩都知道')
        if yyy==1:
            part_y() 
        elif yyy==2:
            part_yz()
        elif yyy==3:
            part_yh()
        else:
            end=sj.now()-start
            print('即将\033[10;31m退出\033[0m,','本次使用时间:',end,'\n程序将在5秒后关闭,谢谢使用')
            exitings(5)
            tc()



from sys import path
path.append("..")
#import sys
#print(sys.path)
from e.__init__ import *
from k.Mac import *
from sys import exit as tc
from sys import stdout
import webbrowser
import os
now_path=os.path.abspath(os.curdir)
#os.system('cd '+now_path)
#os.system('ls -a')
def user_key():
    make=open(now_path+'/.txt',mode='a+')
    make.close()
    with open(now_path+'/.txt',mode='r') as disable:
    #print(disable.tell())#
        disable=disable.read()
        if mac in disable:
            stdout.write('\n您的设备码在本程序的黑名单中,禁止使用')
            exitings(2)
            tc('黑名单用户,禁止使用')
    import base64 as bs64;username=bs64.b32decode(bs64.b64decode(bs64.b16decode(bs64.b85decode(bs64.b64decode("".join(map(chr,[83, 68, 104, 108, 79, 86, 108, 72, 89, 121, 48, 122, 97, 107, 103, 52, 75, 70, 86, 111, 83, 70, 112, 51, 81, 50, 70, 73, 79, 71, 86, 68, 90, 85, 103, 52, 84, 84, 66, 122, 83, 68, 104, 108, 83, 88, 86, 72, 74, 108, 90, 74, 97, 107, 103, 52, 86, 106, 108, 107, 82, 121, 104, 56, 83, 121, 49, 73, 79, 70, 90, 68, 99, 48, 100, 106, 89, 68, 78, 120, 83, 68, 103, 122, 80, 50, 70, 72, 89, 49, 108, 120, 89, 107, 103, 52, 77, 122, 57, 104, 82, 50, 78, 90, 99, 87, 73, 61]
    ))).decode('utf-8')).decode('utf-8')).decode('utf-8')).decode('utf-8')).decode('utf-8');key=bs64.b64decode(bs64.b32decode(bs64.b16decode(bs64.b64decode('NEQ0RDVBNTY0RDM1MzIzMjRDNDI0NjQ3NTE1NzUzNDg0NzQ2NTk0NzQ1NUE1QTM1NDg1NTNEM0QzRDNEM0QzRA==').decode('utf-8')).decode('utf-8')).decode('utf-8')).decode('utf-8')
    def print(*arg,end='\n'):
        global print
        if key in arg or username in arg:
            with open(now_path+"./.txt", mode='a+',encoding='utf-8') as hmd_add:
                hmd_add.writelines(fj)
            stdout.write('非法操作，已进入黑名单')
        arg=''.join(str(i) for i in arg)
        stdout.write(arg+end)
    times=3
    assert times>=0,tc()
    assert times<=3,tc()
    print('\n虹源三式提醒您:请输入Username和key')
    while True:
        k_input=input('Username:')
        u_input=input('key:')
        if k_input==key and u_input==username:#后续加入其他账号
            print('\033[6;32m超级管理员,欢迎使用\033[0m\033[1;1m')
            break
        elif k_input!=key or u_input!=username:
            times=times-1
                    #with open('disable.txt',mode='a+',encoding='utf-8') as Vwt:
                      # Vwt.writeline(886-1)
            print('密码或用户名错误,你还有',times,'次机会')                
        else:
            times=times-1
            print('密码或用户名错误,你还有',times,'次机会')
        if times<=0:
            with open(now_path+"/.txt", mode='a+',encoding='utf-8') as hmd_add:
                fj=('%s'%mac)
                hmd_add.writelines(fj)
                if mac in fj:
                    print('已加入黑名单')
                    exitings(1)
                    tc('禁止使用')
                else:
                    print('程序\033[1;31mERROR\033[0m,请联系lwb29@qq.com')
                    exitings(3)
                    tc()


from setuptools import setup, find_packages
import os
__author__ = '神秘的·'
__project_start_time__='2020'
__date_end_time__ = '2021/7,2021/8'
HERE = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(HERE, "README.rst")) as fid:
    R= fid.read()
setup(
    name='sycc', # 名称 #test
    py_modules=['core','__init__','run'],
    version='0.5.71',#sycc0.5.7#ycc-test0.5.8
    description='三圆计算器,cmd或shell(Terminal) sycc命令开始运行,ps:ycc是原版,sycc是因作者需要而定制版(不推荐下载) ycc-tset版本是ycc和sycc测试上传版本(请勿下载)', # 
    long_description = R,
   # long_description_content_type='text/markdown',
    classifiers=[
    'Natural Language :: Chinese (Simplified)',
    'Development Status :: 6 - Mature',
    'Operating System :: Microsoft :: Windows',
    'Operating System :: POSIX :: Linux',
    'Operating System :: Android',
    'Topic :: Scientific/Engineering :: Mathematics',
    'Topic :: Terminals',
    'Topic :: System :: Shells',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3 :: Only',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Intended Audience :: Developers',],  #new
    keywords=['ycc','3y','a_3y','Circle','圆','圆柱','圆环','py','Chinese','sycc',
    'python','windows','linux','3','y','yc','yz'],# 关键字 #test
    author=__author__, # 作者
    author_email='3046479366@qq.com', 
    url='http://pypi.org/project/ycc', # 包含包的项目地址
    license='MIT', # 授权方式
    packages=["p","k","e"],#未修改#"p","k","e",
    python_requires='>=3.6',
    platfrom=['any'],
    install_requires=['pdsystem>=1.0.4'],
    entry_points = {
        'console_scripts': [
            'sycc = run:main',
        ]
    },
    project_urls = {
    'pydroid(python for android仅限中国大陆使用': 'https://wws.lanzoui.com/iK2GFm24t3a',
    'pydroid文件密码python' : 'https://wws.lanzoux.com/iK2GFm24t3a'
    },
    include_package_data=True,
    zip_safe=False,
)


from p.__init__ import *
from sys import path
path.append('..')
from e.__init__ import *
import platform
os=platform.system()
pai2='π'
def part_yz():#圆柱
    while True:
        r=input('请输入半径:')#半径输入
        try:
            r=eval(r)
            if r<=0:
                print('请输入有效数字')
                switch(1)
                break
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,KeyboardInterrupt,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError):
            print('请输入有效数字')
        H=input('请输入高:')#高输入 
        try:
            H=eval(H)
            if H<0:
                print('请输入有效数字')
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            print('请输入有效数字')
        try:
            if H<=0 and r<=0:#请勿删除，仿照yh.py
                print('①.半径和高>0\n②.2s后重新选择圆柱模式使用\n\033[7;35mtips\033[0m\033[1;1m')
                switch(3)
                break
        except Exception:
            print('出现\033[6;31mError\033[0m\n')
            print('请选择\033[6;36m圆柱\033[0m\033[1;1m模式重试')
            switch(2)
            break
        print('【圆柱】')
        aboutpi()
        if os=='Linux':
            xxx=input('请输入(\033[1;32m1,2,3,4,5\033[0m\033[1;1m)中的一个数字:')
        elif os=='Windows':
            xxx=input('请输入1~5中的数字')
        try:
            xxx=int(xxx)
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            print('请输入有效数字')
        try:
            if xxx>5 or xxx<=0:
                end1=sj.now()-start
                print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
                exitings(5)
                tc('谢谢使用')
            elif xxx==5:
                print('-'*40)
                print('切换模式')
                switch(0.1)
                break
            elif xxx==1:
                dw()
                sU=r*r*3.14#上圆s
                sD=sU*2#双圆s
                d=2*r  #直径
                C=d*3.14 #周长
                Sc=C*H #侧s
                S=sD+Sc #表s
                V=sU*H
                if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                    print('请重新输入半径和高')
                    print('请圆柱模式，再次尝试运行')
                    switch(0.5)
                    break
                elif r>0 and H>0:
                    dw()
                    print('======计算结果======')
                    print('当半径=',r,'直径=',d,'高=',H,'时')
                    print('\n一个圆的周长=','{:.5f}'.format(C))
                    print('一个圆的面积=','{:.5f}'.format(sU))
                    print('两个圆的面积=','{:.5f}'.format(sD))
                    print('圆柱的侧面积=','{:.5f}'.format(Sc))
                    print('圆柱的体积=','{:.5f}'.format(V))
                    print('圆柱的表面积=','{:.5f}'.format(S))
                else:
                    print('请重新输入半径和高')
                    print('请圆柱模式，再次尝试运行')
            elif xxx==2:
                sU=r*r*pai1#上圆s
                sD=sU*2#双圆s
                d=2*r  #直径
                C=d*pai1 #周长
                Sc=C*H #侧s
                S=sD+Sc #表s
                V=sU*H
                if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                    print('请重新输入半径和高，因为其中一个小于0或者数太小了，就像0.0001这样的，所以停止运行了')
                    print('请重新选择圆柱模式，再次尝试运行')
                    switch(0.5)
                    break
                elif r>0 and H>0:
                    dw()
                    print('=====计算结果=====')
                    print('当半径=',r,'直径=',d,'高=',H,'时')
                    print('\n一个圆的周长=','{:.5f}'.format(C))
                    print('一个圆的面积=','{:.5f}'.format(sU))
                    print('两个圆的面积=','{:.5f}'.format(sD))
                    print('圆柱的侧面积=','{:.5f}'.format(Sc))
                    print('圆柱的体积=','{:.5f}'.format(V))
                    print('圆柱的表面积=','{:.5f}'.format(S))
                else:
                    print('重新输入半径和高')
            elif xxx==3:
                sU=r*r#上圆s 
                sD=sU*2#双圆s 
                d=2*r  #直径
                C=d #周长
                Sc=C*H #侧s 
                S=sD+Sc #表s 
                V=sU*H
                if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                    print('请重新输入半径和高')
                    print('请圆柱模式，再次尝试运行')
                    switch(0.5)
                    break
                elif r>0 and H>0:
                    dw()
                    print('=====计算结果=====')
                    print('当半径=',r,'直径=',d,'高=',H,'时')
                    print('\n一个圆的周长=','{:.5f}'.format(C),pai2)
                    print('一个圆的面积=','{:.5f}'.format(sU),pai2)
                    print('两个圆的面积=','{:.5f}'.format(sD),pai2)
                    print('圆柱的侧面积=','{:.5f}'.format(Sc),pai2)
                    print('圆柱的体积=','{:.6f}'.format(V),pai2)
                    print('圆柱的表面积=','{:.5f}'.format(S),pai2)
                else:
                    print('重新输入半径和高')
            elif xxx==4:
                defpi=input('请输入要自定义的π(大于等于3且小于3.2)->')
                try:
                    defpi=eval(defpi)
                except (IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
                    print('请输入指定范围的数字')
                except ZeroDivisionError:
           	     print('除数不能为0')
           	     print('请使用正确符号或正确数字')
                if defpi<3 or defpi >3.2:
                        switch(0.3)
                        break
                if defpi >=3 and defpi <3.2:
                    sU=r*r*defpi#上圆s
                    sD=sU*2#双圆s
                    d=2*r  #直径
                    C=d*defpi #周长
                    Sc=C*H #侧s
                    S=sD+Sc #表s
                    V=sU*H#体积
                    if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                        print('请重新输入半径和高')
                        switch(0.5)
                        break
                    elif r>0 and H>0:
                        dw()
                        print('=====计算结果=====')
                        print('当半径=',r,'直径=',d,'高=',H,'π=',defpi,'时')
                        print('\n一个圆的周长=','{:.6f}'.format(C))
                        print('一个圆的面积=','{:.6f}'.format(sU))
                        print('两个圆的面积=','{:.6f}'.format(sD))
                        print('圆柱的侧面积=','{:.6f}'.format(Sc))
                        print('圆柱的体积=','{:.6f}'.format(V))
                        print('圆柱的表面积=','{:.6f}'.format(S))
                    else:
                        print('重新输入半径和高')
            else:
                end1=sj.now()-start
                print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
                exitings(5)
                tc('谢谢使用')
        except Exception:
            print('\n圆柱beta报告:在本模式中您的操作出现\033[1;1m\033[6;31mError\033[0m\n','\b已为您自动跳转选择模式,请选择圆柱模式')
            switch(1)
            break

